import calendar_ids from '../database/calendar_ids';
import { getConnection } from '../database/initDatabase';

interface CalendarEvent {
    event_id: string;
    calendar_id: string;
    start_time: Date;
    end_time: Date;
    status_val: string;
    updated_time: Date;
    transparency: string;
}

async function getAllEventsFromDatabase(calendarId: string, start: Date, end: Date) {
    return new Promise<CalendarEvent[]>(async (resolve, reject) => {
        let conn;
        try {
            if ((await calendar_ids.checkIfCalendarExists(calendarId)) === false) {
                reject('Calendar does not exist ' + calendarId);
                return;
            }
            conn = await getConnection();

            const query =
                'SELECT * FROM `calendar_events` WHERE `calendar_id` = ? AND ((`start_time` >= ? AND `start_time` <= ?) OR (`end_time` >= ? AND `end_time` <= ?) OR (`start_time` <= ? AND `end_time` >= ?)) ORDER BY `start_time`';
            const params = [calendarId, start, end, start, end, start, end];

            const rows = await conn.query(query, params);

            resolve(rows as CalendarEvent[]);
        } catch (error) {
            console.log('getAllEventsFromDatabase error', error);
            reject(error);
        } finally {
            if (conn) {
                conn.end();
            }
        }
    });
}

async function getAllBusyEventsFromDatabase(calendarId: string, start: Date, end: Date) {
    return new Promise<CalendarEvent[]>(async (resolve, reject) => {
        let conn;
        try {
            if ((await calendar_ids.checkIfCalendarExists(calendarId)) === false) {
                reject('Calendar does not exist ' + calendarId);
                return;
            }
            conn = await getConnection();

            const query =
                'SELECT * FROM `calendar_events` WHERE `calendar_id` = ? AND `status_val` = "confirmed" AND `transparency` = "opaque" AND ((`start_time` >= ? AND `start_time` <= ?) OR (`end_time` >= ? AND `end_time` <= ?) OR (`start_time` <= ? AND `end_time` >= ?)) ORDER BY `start_time`';
            const params = [calendarId, start, end, start, end, start, end];

            const rows = await conn.query(query, params);

            resolve(rows as CalendarEvent[]);
        } catch (error) {
            console.log('getAllEventsFromDatabase error', error);
            reject(error);
        } finally {
            if (conn) {
                conn.end();
            }
        }
    });
}

export { getAllEventsFromDatabase, getAllBusyEventsFromDatabase };
