// External libraries
import { calendar_v3, google } from 'googleapis';

// Configuration
import { googleSyncMaxDays } from '../config';

// Redis related imports
import redisClient from '../redis/init';
import MyRedisKeys from '../redis/keys';

// Database related imports
import { getConnection } from '../database/initDatabase';
import { getUser } from '../database/user';

// Calendar related imports
import { getAccessToken, getOAuthClient } from '../calendar/oauthAccess';

// Event related imports
import { insertEvent } from './misc';
import { refreshOpenHours } from './openHours';

// Request counter
import countGoogleRequestStatUp from '../requestCounter';
import syncCalendar from './refreshSync';

async function updateEvents() {
    let conn;
    try {
        conn = await getConnection();

        const currentTime = new Date();

        const rows = await conn.query('SELECT * FROM `calendar_ids` WHERE `is_disabled` IS NULL AND `sync_token` IS NOT NULL AND (`next_sync` < ? OR `next_sync` IS NULL) ORDER BY RAND() LIMIT 1', [
            currentTime,
        ]);
        conn.end();

        if (rows.length >= 1) {
            const row = rows[0];

            await syncCalendar(row, false);
        }
    } catch (error) {
        console.error(error);
    } finally {
        if (conn) conn.end();
    }
}

export default updateEvents;
