// External libraries
import { calendar_v3, google } from 'googleapis';

// Configuration
import { googleSyncMaxDays } from '../config';

// Redis related imports
import redisClient from '../redis/init';
import MyRedisKeys from '../redis/keys';

// Database related imports
import { getConnection } from '../database/initDatabase';
import { getUser } from '../database/user';

// Calendar related imports
import { getAccessToken, getOAuthClient } from '../calendar/oauthAccess';

// Event related imports
import { insertEvent } from './misc';
import { refreshOpenHours } from './openHours';

// Request counter
import countGoogleRequestStatUp from '../requestCounter';
import syncCalendar from './refreshSync';

async function updateWebhooks() {
    let conn;
    try {
        conn = await getConnection();

        const currentTime = new Date(new Date().getTime() + 1000 * 60 * 30); // when it expires in 30 minutes

        // sync_token !== null AND (webhook_channel_id === NULL OR webhook_expires_at < new Date())
        const rows = await conn.query(
            'SELECT * FROM `calendar_ids` WHERE `is_disabled` IS NULL AND `sync_token` IS NOT NULL AND (`webhook_channel_id` IS NULL OR `webhook_expires_at` < ?) ORDER BY RAND() LIMIT 1',
            [currentTime]
        );
        conn.end();

        if (rows.length >= 1) {
            const row = rows[0];

            await syncCalendar(row, false);

            // wait 2 seconds
            await new Promise((resolve) => setTimeout(resolve, 2000));
            await updateWebhooks();
        }
    } catch (error) {
        console.error(error);
    } finally {
        if (conn) conn.end();
    }
}

export default updateWebhooks;
