import e from 'express';

// crash if no recaptcha keys are set
if (!process.env.RECAPTCHA_SITE_KEY || !process.env.RECAPTCHA_SECRET_KEY) {
    throw new Error('no recaptcha keys found!');
}

const encodedSecretKey = encodeURIComponent(process.env.RECAPTCHA_SECRET_KEY);

async function verifyCaptcha(token: string, ip?: string): Promise<boolean> {
    return new Promise(async (resolve, reject) => {
        console.log('verifying captcha token from ip:', ip);

        if (typeof token !== 'string' || token.trim() === '') {
            reject('Invalid token');
            return;
        }

        if (!encodedSecretKey) {
            reject('captcha secret not set');
            return;
        }

        let url;
        if (!ip) {
            url = 'https://www.google.com/recaptcha/api/siteverify?secret=' + encodedSecretKey + '&response=' + encodeURIComponent(token);
        } else {
            url = 'https://www.google.com/recaptcha/api/siteverify?secret=' + encodedSecretKey + '&response=' + encodeURIComponent(token) + '&remoteip=' + ip;
        }

        try {
            const res = await fetch(url, { method: 'POST' });
            const json = await res.json();

            if (json.success) {
                resolve(true);
            } else {
                reject('captcha failed');
            }
        } catch (error) {
            reject('Error verifying captcha');
            console.error('Error verifying captcha:', error);
        }
    });
}

export default verifyCaptcha;
