import path from 'path';
import { StoreSettings } from './database/store';

import dotenv from 'dotenv';
dotenv.config();

const webPort = process.env.BACKEND_PORT;
const webHost = process.env.BACKEND_HOST;

const publicFolder = path.resolve(__dirname + '/../public/');

const clientId = process.env.GOOGLE_CLIENT_ID; // Google API client ID
const clientSecret = process.env.GOOGLE_CLIENT_SECRET; // Google API client secret

const domain = process.env.DOMAIN;

const cacheEventsTime = 1000 * 60 * 10; // 10 minutes

const googleSyncMaxDays = Number(process.env.GOOGLE_SYNC_MAX_DAYS);

const defaultPrimaryCalendarId = 'primary';

const databaseCredentials = {
    host: process.env.MARIADB_HOST,
    port: Number(process.env.MARIADB_PORT),
    user: process.env.MARIADB_USERNAME,
    database: process.env.MARIADB_DATABASE,
    password: process.env.MARIADB_PASSWORD,
};

const GLOBAL_calendar_min_earliest_booking_time = 15; // because of email verification

const defaultUserSettings: StoreSettings = {
    calendar_max_future_booking_days: 7,
    calendar_min_earliest_booking_time: 0, // in minutes (+ GLOBAL_calendar_min_earliest_booking_time)
    calendar_using_primary_calendar: true,
};

const REDIS_URL = 'redis://' + process.env.REDIS_HOST + ':' + process.env.REDIS_PORT;

const publicURL = process.env.PUBLIC_URL;

const GLOBAL_sync_calendar_every_minutes = Number(process.env.SYNC_CALENDAR_EVERY_MINUTES) || 360; // 6 hours
const GLOBAL_google_webhook_time_delay = Number(process.env.GOOGLE_WEBHOOK_TIME_DELAY_SECONDS) || 5; // 5 seconds

let notifyBeforeAppointment: number[] = [1440, 60]; // in minutes // the order is important! -> index 0 is the first notification, last index is the last notification

//sort notifyBeforeAppointment
notifyBeforeAppointment.sort((a, b) => b - a);

export {
    webPort,
    webHost,
    defaultPrimaryCalendarId,
    publicFolder,
    clientId,
    clientSecret,
    databaseCredentials,
    defaultUserSettings,
    cacheEventsTime,
    GLOBAL_calendar_min_earliest_booking_time,
    GLOBAL_sync_calendar_every_minutes,
    GLOBAL_google_webhook_time_delay,
    domain,
    googleSyncMaxDays,
    REDIS_URL,
    publicURL,
    notifyBeforeAppointment,
};
