import { CalendarEvent } from '../database/reservedCustomer';
import { getActivity } from '../database/services';
import { getUser } from '../database/user';

interface DateText {
    activityName: string;
    username: string;
    day: string;
    dayNumber: string;
    month: string;
    year: string;
    startTime: string;
    endTime: string;
}
async function getDateText(event: CalendarEvent): Promise<DateText> {
    return new Promise(async (resolve, reject) => {
        try {
            const locale = 'de-DE';

            let activityName = 'unknown';

            try {
                const activity = await getActivity(event.store_id, event.activity_id, false);
                activityName = activity.name;
            } catch (error) {}

            const user = await getUser(event.user_id);
            const username = user.username;
            const day = event.time_start.toLocaleDateString(locale, { weekday: 'long' });
            const dayNumber = event.time_start.getDate().toString();
            const month = event.time_start.toLocaleDateString(locale, { month: 'long' });
            const year = event.time_start.getFullYear().toString();
            const startTime = event.time_start.toLocaleTimeString(locale, { hour: 'numeric', minute: 'numeric' });
            const endTime = event.time_end.toLocaleTimeString(locale, { hour: 'numeric', minute: 'numeric' });

            const dateText: DateText = {
                activityName: activityName,
                username: username,
                day: day,
                dayNumber: dayNumber,
                month: month,
                year: year,
                startTime: startTime,
                endTime: endTime,
            };

            resolve(dateText);
        } catch (err) {
            reject(err);
        }
    });
}

export { DateText, getDateText };
