import MyEvents, { CalendarEvent } from '../database/reservedCustomer';
import { getStore } from '../database/store';
import { getUser } from '../database/user';
import { User } from '../user/types';
import { getDateText } from './dateText';
import getConnection from './getConnection';

async function sendVerifyMail(event: CalendarEvent) {
    try {
        const queue = 'kk.mails';
        const conn = await getConnection();

        // Sender
        const ch2 = await conn.createChannel();

        const verifyURL = MyEvents.generateEMailVerificationLink(event.customer_id);
        const cancelURL = MyEvents.generateEMailCancelLink(event.customer_id);

        const store = await getStore(event.store_id);

        let data = {
            m: event.customer_email, // UserMail
            t: 'embedVerificationZeitAdler', // TemplateId
            l: 'de', // LanguageId
            // BodyData
            b: {
                name: event.customer_name,
                verifyURL: verifyURL,
                cancelURL: cancelURL,
                address: store.address,
                ...(await getDateText(event)),
            },
        };

        ch2.sendToQueue(queue, Buffer.from(JSON.stringify(data)));
        console.log('Sent:', data);
    } catch (error) {
        console.error('Error sending verify mail', error);
    }
}

async function sendMailIsVerifiedMail(event: CalendarEvent) {
    try {
        const queue = 'kk.mails';
        const conn = await getConnection();

        // Sender
        const ch2 = await conn.createChannel();

        const cancelURL = MyEvents.generateEMailCancelLink(event.customer_id);

        const store = await getStore(event.store_id);

        let data = {
            m: event.customer_email, // UserMail
            t: 'embedEmailVerifiedZeitAdler', // TemplateId
            l: 'de', // LanguageId
            // BodyData
            b: {
                name: event.customer_name,
                cancelURL: cancelURL,
                address: store.address,
                ...(await getDateText(event)),
            },
        };

        ch2.sendToQueue(queue, Buffer.from(JSON.stringify(data)));

        try {
            await sendNewAppointmentForEmployeeMail(event);
        } catch (error) {
            console.log('error sending sendNewAppointmentForEmployeeMail');
            console.error(error);
        }
    } catch (error) {
        console.error('Error sending mail is verified mail', error);
    }
}

async function sendNewAppointmentForEmployeeMail(event: CalendarEvent) {
    try {
        const user = await getUser(event.user_id);
        if (!user.email) return;

        const queue = 'kk.mails';
        const conn = await getConnection();

        // Sender
        const ch2 = await conn.createChannel();

        const cancelURL = MyEvents.generateEMailCancelLink(event.customer_id);

        const store = await getStore(event.store_id);

        let data = {
            m: user.email, // UserMail
            t: 'embedEmployeeNewNotificationZeitAdler', // TemplateId
            l: 'de', // LanguageId
            // BodyData
            b: {
                name: event.customer_name,
                customerMessage: event.customer_message,
                customerEMail: event.customer_email,
                cancelURL: cancelURL,
                address: store.address,
                ...(await getDateText(event)),
            },
        };

        ch2.sendToQueue(queue, Buffer.from(JSON.stringify(data)));
    } catch (error) {
        console.error('Error sending new appointment for employee mail', error);
    }
}

export default sendVerifyMail;
export { sendMailIsVerifiedMail, sendNewAppointmentForEmployeeMail };
