import { StoreID } from '../database/store';
import { getAllUsersIDsByStoreID } from '../database/user';
import redisClient from './init';

async function clearRedisCache(store_id: StoreID) {
    return new Promise(async (resolve, reject) => {
        try {
            const keys = await redisClient.keys(`store:${store_id}*`);
            //console.log('keys', keys);

            if (keys.length > 0) await redisClient.del(keys);

            const users = await getAllUsersIDsByStoreID(store_id);

            for (const user_id of users) {
                const userKeys = await redisClient.keys(`user:${user_id}*`);
                //console.log('userKeys', userKeys);

                if (userKeys.length > 0) await redisClient.del(userKeys);
            }

            resolve(true);
        } catch (error) {
            console.error(error);
            reject();
        }
    });
}

export default clearRedisCache;
