import { StoreID } from '../database/store';
import crypto from 'crypto';

const dayToString = (day: Date) =>
    day.toLocaleDateString('de-DE', {
        day: '2-digit',
        month: '2-digit',
        year: '2-digit',
    });

const MyRedisKeys = {
    calendarSyncLock: (calendarId: string) => 'calendar:' + calendarId + ':sync:locked',
    userBookingLock: (userId: string, day: Date) => 'userLockBooking:' + userId + ':' + dayToString(day),
    userBookingLockUnique: (userId: string, day: Date, date: Date) => MyRedisKeys.userBookingLock(userId, day) + ':' + date.getTime(),
    appointmentNotificationLock: (customer_id: string) => 'appointmentNotificationLock:' + customer_id,

    calendarOpenHours: (storeId: string) => 'store:' + storeId + ':calendar:openHours',
    storeCache: (storeId: string) => 'store:' + storeId + ':cache',
    freeTimeOfDayCache: (storeID: StoreID, _userIDs: string[], bookTimeLength: number, day: Date) => {
        // sort userIDs by alphabetical order
        let userIDs = _userIDs.sort();

        //create text from userIDs
        let text = '';
        for (const userID of userIDs) {
            text += userID;
        }

        // create hash 256
        const hash = crypto.createHash('md5').update(text).digest('hex');

        const dateStr = dayToString(day);

        return 'store:' + storeID + ':' + hash + ':' + dateStr + ':' + bookTimeLength + ':freeTimeOfDay';
    },

    freeTimeFromOneUserCache: (userId: string, bookTimeLength: number, date: Date) => 'user:' + userId + ':' + dayToString(date) + ':' + bookTimeLength + ':freeTimeFromOneUser',
    userCache: (userId: string) => 'user:' + userId + ':cache',
};

export default MyRedisKeys;
